@@ -24,8 +24,7 @@
 #ifndef __MCD_ACCOUNT_H__
 #define __MCD_ACCOUNT_H__
 
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/enums.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 #define MCD_TYPE_ACCOUNT         (mcd_account_get_type ())
@@ -80,10 +79,10 @@ struct _McdAccountClass
 };
 
 GType mcd_account_get_type (void);
-McdAccount *mcd_account_new (McdAccountManager *account_manager,
-			     const gchar *name);
 
-TpDBusDaemon *mcd_account_get_dbus_daemon (McdAccount *account);
+McdAccount *mcd_account_new (McdAccountManager *account_manager,
+    const gchar *name,
+    McdConnectivityMonitor *minotaur);
 
 void mcd_account_delete (McdAccount *account, McdAccountDeleteCb callback,
                          gpointer user_data);
@@ -118,19 +117,9 @@ void mcd_account_get_requested_presence (McdAccount *account,
 					 const gchar **status,
 					 const gchar **message);
 
-gboolean mcd_account_get_connect_automatically (McdAccount *account);
 gboolean mcd_account_would_like_to_connect (McdAccount *account);
-void mcd_account_get_automatic_presence (McdAccount *account,
-					 TpConnectionPresenceType *presence,
-					 const gchar **status,
-					 const gchar **message);
-
-gchar *mcd_account_get_normalized_name (McdAccount *account);
-
-gchar *mcd_account_get_alias (McdAccount *account);
 
 TpConnectionStatus mcd_account_get_connection_status (McdAccount *account);
-TpConnectionStatusReason mcd_account_get_connection_status_reason (McdAccount *account);
 
 McdConnection *mcd_account_get_connection (McdAccount *account);
 
@@ -140,7 +129,7 @@ gboolean mcd_account_check_request (McdAccount *account, GHashTable *request,
 gboolean mcd_account_parameter_is_secret (McdAccount *self,
                                               const gchar *name);
 
-void mcd_account_property_changed (McdAccount *account, const gchar *name);
+void mcd_account_altered_by_plugin (McdAccount *account, const gchar *name);
 
 gchar * mcd_account_dup_display_name (McdAccount *self);
 
@@ -158,6 +147,17 @@ gchar * mcd_account_dup_icon (McdAccount *self);
 
 gchar * mcd_account_dup_nickname (McdAccount *self);
 
+McdConnectivityMonitor *mcd_account_get_connectivity_monitor (
+    McdAccount *self);
+
+gboolean mcd_account_get_waiting_for_connectivity (McdAccount *self);
+void mcd_account_set_waiting_for_connectivity (McdAccount *self,
+    gboolean waiting);
+
+void mcd_account_connection_proceed (McdAccount *account, gboolean success);
+void mcd_account_connection_proceed_with_reason
+    (McdAccount *account, gboolean success, TpConnectionStatusReason reason);
+
 G_END_DECLS
 
 #endif
