@@ -33,19 +33,11 @@
 
 G_BEGIN_DECLS
 
-/* retrieves the channel handlers' capabilities, in a format suitable for being
- * used as a parameter for the telepathy "AdvertiseCapabilities" method */
-G_GNUC_INTERNAL GPtrArray *_mcd_dispatcher_get_channel_capabilities (
-    McdDispatcher *dispatcher);
-
-/* retrieves the channel handlers' capabilities, in a format suitable for being
- * used as a parameter for the telepathy "SetSelfCapabilities" method */
-G_GNUC_INTERNAL GPtrArray *_mcd_dispatcher_get_channel_enhanced_capabilities (
-    McdDispatcher *dispatcher);
-
 /* not exported */
-G_GNUC_INTERNAL void _mcd_dispatcher_take_channels (
-    McdDispatcher *dispatcher, GList *channels, gboolean requested,
+G_GNUC_INTERNAL void _mcd_dispatcher_add_channel (
+    McdDispatcher *dispatcher,
+    McdChannel *channel,
+    gboolean requested,
     gboolean only_observe);
 G_GNUC_INTERNAL
 void _mcd_dispatcher_add_channel_request (McdDispatcher *dispatcher,
@@ -62,9 +54,6 @@ G_GNUC_INTERNAL void _mcd_dispatcher_add_connection (McdDispatcher *self,
 G_GNUC_INTERNAL GPtrArray *_mcd_dispatcher_dup_client_caps (
     McdDispatcher *self);
 
-G_GNUC_INTERNAL McdClientRegistry *_mcd_dispatcher_get_client_registry (
-    McdDispatcher *self);
-
 G_END_DECLS
 
 #endif /* MCD_DISPATCHER_H */
