@@ -38,7 +38,7 @@ def preseed(q, bus, fake_accounts_service):
     accounts_dir = os.environ['MC_ACCOUNT_DIR']
 
     try:
-        os.mkdir(accounts_dir, 0700)
+        os.mkdir(accounts_dir, 0o700)
     except OSError:
         pass
 
