@@ -185,14 +185,9 @@ def test_channel_creation(q, bus, account, client, conn,
     assertEquals(channel.object_path, e.args[2])
     assertEquals(channel_immutable, e.args[3])
 
-    # CR emits Succeeded (or in Mardy's version, Account emits Succeeded)
-    q.expect_many(
-            EventPattern('dbus-signal', path=account.object_path,
-                interface=cs.ACCOUNT_IFACE_NOKIA_REQUESTS, signal='Succeeded',
-                args=[request_path]),
-            EventPattern('dbus-signal', path=request_path,
-                interface=cs.CR, signal='Succeeded'),
-            )
+    # CR emits Succeeded
+    q.expect('dbus-signal', path=request_path,
+                interface=cs.CR, signal='Succeeded')
 
     # Close the channel
     channel.close()
